NERtcDesktopDeviceInfo class

Annotations
  • @JsonSerializable.new()

Constructors

NERtcDesktopDeviceInfo({required String deviceName, required String deviceId, required int transportType, required bool suspectedUnavailable, required bool systemDefaultDevice, required bool systemPriorityDevice})
NERtcDesktopDeviceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

deviceId ↔ String
设备ID
getter/setter pair
deviceName ↔ String
设备名称
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suspectedUnavailable ↔ bool
是否是不推荐设备
getter/setter pair
systemDefaultDevice ↔ bool
是否是系统默认设备
getter/setter pair
systemPriorityDevice ↔ bool
是否是 SDK 优先选择设备
getter/setter pair
transportType ↔ int
设备链接类型,分别指向 NERtcAudioDeviceTransportType 及 NERtcVideoDeviceTransportType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited