NERtcJoinChannelOptions class

joinChannel 时的一些可选信息

Annotations
  • @JsonSerializable.new()

Constructors

NERtcJoinChannelOptions(String? customInfo, String? permissionKey)
NERtcJoinChannelOptions.fromJson(Map<String, dynamic> json)
factory

Properties

customInfo → String?
自定义信息,最长支持127个字符, 若超过127个字符,该参数无效。
final
hashCode → int
The hash code for this object.
no setterinherited
permissionKey → String?
权限密钥。能控制通话时长及媒体权限能力。
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited