NERtcRectangle class

Annotations
  • @JsonSerializable.new()

Constructors

NERtcRectangle({required int x, required int y, required int width, required int height})
NERtcRectangle.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
待共享区域的高。
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int
待共享区域的宽。
getter/setter pair
x ↔ int
左上角的横向偏移。
getter/setter pair
y ↔ int
左上角的纵向偏移。
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited