NERtcScreenCaptureParameters class

屏幕共享编码参数配置。用于衡量编码质量。

Annotations
  • @JsonSerializable.new()

Constructors

NERtcScreenCaptureParameters({NERtcScreenProfileType profile = NERtcScreenProfileType.kNERtcScreenProfileNone, NERtcVideoDimensions? dimensions, int frameRate = 5, int minFrameRate = 0, int bitRate = 0, int minBitRate = 0, bool captureMouseCursor = false, bool windowFocus = false, List<int> excludeWindowList = const [], int contentPrefer = NERtcSubStreamContentPrefer.motion, int preference = NERtcDegradationPreference.degradationDefault, bool enableHighPerformance = false, bool enableHighLight = false, int highLightWidth = 6, int highLightColor = 0, int highLightLength = 0, bool excludeHighLightBox = false, bool forceUpdateData = false})
NERtcScreenCaptureParameters.fromJson(Map<String, dynamic> json)
factory

Properties

bitRate ↔ int
getter/setter pair
captureMouseCursor ↔ bool
getter/setter pair
contentPrefer ↔ int
getter/setter pair
dimensions ↔ NERtcVideoDimensions?
getter/setter pair
enableHighLight ↔ bool
getter/setter pair
enableHighPerformance ↔ bool
getter/setter pair
excludeHighLightBox ↔ bool
getter/setter pair
excludeWindowList ↔ List<int>
getter/setter pair
forceUpdateData ↔ bool
getter/setter pair
frameRate ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
highLightColor ↔ int
getter/setter pair
highLightLength ↔ int
getter/setter pair
highLightWidth ↔ int
getter/setter pair
minBitRate ↔ int
getter/setter pair
minFrameRate ↔ int
getter/setter pair
preference ↔ int
getter/setter pair
profile ↔ NERtcScreenProfileType
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
windowFocus ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited