NERtcScreenCaptureSourceInfo class

Annotations
  • @JsonSerializable.new()

Constructors

NERtcScreenCaptureSourceInfo({required NERtcScreenCaptureSourceType type, required int sourceId, required String sourceName, required NERtcThumbImageBuffer thumbImage, required NERtcThumbImageBuffer iconImage, required String processPath, required String sourceTitle, required bool primaryMonitor})
NERtcScreenCaptureSourceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconImage ↔ NERtcThumbImageBuffer
The image content of the icon. See ThumbImageBuffer.
getter/setter pair
primaryMonitor ↔ bool
Determines whether the screen is the primary display:
getter/setter pair
processPath ↔ String
The process to which the window belongs. UTF-8 encoding.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceId ↔ int
The window ID for a window or the display ID for a screen.
getter/setter pair
sourceName ↔ String
The name of the window or screen. UTF-8 encoding.
getter/setter pair
sourceTitle ↔ String
The title of the window. UTF-8 encoding.
getter/setter pair
thumbImage ↔ NERtcThumbImageBuffer
The image content of the thumbnail. See ThumbImageBuffer.
getter/setter pair
type ↔ NERtcScreenCaptureSourceType
The type of the shared target. NERtcScreenCaptureSourceType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited