NERtcSpatializerRoomProperty class

Annotations
  • @JsonSerializable.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
material ↔ NERtcSpatializerMaterialName
房间材质 #NERtcSpatializerMaterialName,默认值 #kNERtcSpatializerMaterialTransparent
getter/setter pair
reflectionScalar ↔ double
反射比例,默认值 1.0
getter/setter pair
reverbBrightness ↔ double
混响音色亮度,默认值 1.0
getter/setter pair
reverbGain ↔ double
混响增益比例因子,默认值 1.0
getter/setter pair
reverbTime ↔ double
混响时间比例因子,默认值 1.0
getter/setter pair
roomCapacity ↔ NERtcSpatializerRoomCapacity
房间大小 #NERtcSpatializerRoomCapacity,默认值 #kNERtcSpatializerRoomCapacitySmall
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited