AudioEffectApi class

Constructors

AudioEffectApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for AudioEffectApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger → BinaryMessenger?
final
pigeonVar_messageChannelSuffix → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEffectCurrentPosition(int effectId) → Future<int>
getEffectDuration(int effectId) → Future<int>
getEffectPitch(int effectId) → Future<int>
getEffectPlaybackVolume(int effectId) → Future<int>
getEffectSendVolume(int effectId) → Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseAllEffects() → Future<int>
pauseEffect(int effectId) → Future<int>
playEffect(PlayEffectRequest request) → Future<int>
resumeAllEffects() → Future<int>
resumeEffect(int effectId) → Future<int>
setEffectPitch(int effectId, int pitch) → Future<int>
setEffectPlaybackVolume(int effectId, int volume) → Future<int>
setEffectPosition(int effectId, int position) → Future<int>
setEffectSendVolume(int effectId, int volume) → Future<int>
stopAllEffects() → Future<int>
stopEffect(int effectId) → Future<int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>