AudioExternalFrame class

Constructors

AudioExternalFrame({Uint8List? data, int? sampleRate, int? numberOfChannels, int? samplesPerChannel, int? syncTimestamp})

Properties

data ↔ Uint8List?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numberOfChannels ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate ↔ int?
getter/setter pair
samplesPerChannel ↔ int?
getter/setter pair
syncTimestamp ↔ int?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → AudioExternalFrame