AudioMixingApi class
Constructors
- AudioMixingApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
-
Constructor for AudioMixingApi. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pigeonVar_binaryMessenger → BinaryMessenger?
-
final
- pigeonVar_messageChannelSuffix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAudioMixingCurrentPosition(
) → Future< int> -
getAudioMixingDuration(
) → Future< int> -
getAudioMixingPitch(
) → Future< int> -
getAudioMixingPlaybackVolume(
) → Future< int> -
getAudioMixingSendVolume(
) → Future< int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseAudioMixing(
) → Future< int> -
resumeAudioMixing(
) → Future< int> -
setAudioMixingPitch(
int pitch) → Future< int> -
setAudioMixingPlaybackVolume(
int volume) → Future< int> -
setAudioMixingPosition(
int position) → Future< int> -
setAudioMixingSendVolume(
int volume) → Future< int> -
startAudioMixing(
StartAudioMixingRequest request) → Future< int> -
stopAudioMixing(
) → Future< int> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>