ChannelApi class
Constructors
ChannelApi ({BinaryMessenger ? binaryMessenger , String messageChannelSuffix = '' })
Constructor for ChannelApi . The binaryMessenger named argument is
available for dependency injection. If it is left null, the default
BinaryMessenger will be used which routes to the host platform.
Methods
addLiveStreamTask (String channelTag , AddOrUpdateLiveStreamTaskRequest request )
→ Future <int >
adjustLoopBackRecordingSignalVolume (String channelTag , int volume )
→ Future <int >
adjustUserPlaybackSignalVolume (String channelTag , AdjustUserPlaybackSignalVolumeRequest request )
→ Future <int >
clearStatsEventCallback (String channelTag )
→ Future <int >
enableAudioVolumeIndication (String channelTag , EnableAudioVolumeIndicationRequest request )
→ Future <int >
enableEncryption (String channelTag , EnableEncryptionRequest request )
→ Future <int >
enableLocalAudio (String channelTag , bool enable )
→ Future <int >
enableLocalData (String channelTag , bool enabled )
→ Future <int >
enableLocalSubStreamAudio (String channelTag , bool enable )
→ Future <int >
enableLocalVideo (String channelTag , EnableLocalVideoRequest request )
→ Future <int >
enableLoopbackRecording (String channelTag , bool enable )
→ Future <int >
enableMediaPub (String channelTag , int mediaType , bool enable )
→ Future <int >
enableSpatializer (String channelTag , bool enable , bool applyToTeam )
→ Future <int >
enableSpatializerRoomEffects (String channelTag , bool enable )
→ Future <int >
getChannelName (String channelTag )
→ Future <String >
getConnectionState (String channelTag )
→ Future <int >
getFeatureSupportedType (String channelTag , int type )
→ Future <int >
joinChannel (String channelTag , JoinChannelRequest request )
→ Future <int >
leaveChannel (String channelTag )
→ Future <int >
muteLocalAudioStream (String channelTag , bool mute )
→ Future <int >
muteLocalVideoStream (String channelTag , bool mute , int streamType )
→ Future <int >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pushExternalVideoFrame (String channelTag , int streamType , VideoFrame frame )
→ Future <int >
release (String channelTag )
→ Future <int >
removeLiveStreamTask (String channelTag , DeleteLiveStreamTaskRequest request )
→ Future <int >
reportCustomEvent (String channelTag , ReportCustomEventRequest request )
→ Future <int >
sendData (String channelTag , DataExternalFrame frame )
→ Future <int >
sendSEIMsg (String channelTag , SendSEIMsgRequest request )
→ Future <int >
setAudioRecvRange (String channelTag , int audibleDistance , int conversationalDistance , int rollOffMode )
→ Future <int >
setAudioSubscribeOnlyBy (String channelTag , SetAudioSubscribeOnlyByRequest request )
→ Future <int >
setCameraCaptureConfig (String channelTag , SetCameraCaptureConfigRequest request )
→ Future <int >
setChannelProfile (String channelTag , int channelProfile )
→ Future <int >
setClientRole (String channelTag , int role )
→ Future <int >
setExternalVideoSource (String channelTag , int streamType , bool enable )
→ Future <int >
setLocalMediaPriority (String channelTag , SetLocalMediaPriorityRequest request )
→ Future <int >
setLocalPublishFallbackOption (String channelTag , int option )
→ Future <int >
setLocalVideoConfig (String channelTag , SetLocalVideoConfigRequest request )
→ Future <int >
setRangeAudioMode (String channelTag , int audioMode )
→ Future <int >
setRangeAudioTeamID (String channelTag , int teamID )
→ Future <int >
setRemoteHighPriorityAudioStream (String channelTag , SetRemoteHighPriorityAudioStreamRequest request )
→ Future <int >
setRemoteSubscribeFallbackOption (String channelTag , int option )
→ Future <int >
setSpatializerRenderMode (String channelTag , int renderMode )
→ Future <int >
setSpatializerRoomProperty (String channelTag , SpatializerRoomProperty property )
→ Future <int >
setStatsEventCallback (String channelTag )
→ Future <int >
setSubscribeAudioAllowlist (String channelTag , List <int ? > uidArray )
→ Future <int >
setSubscribeAudioBlocklist (String channelTag , List <int ? > uidArray , int streamType )
→ Future <int >
setUpSpatializer (String channelTag )
→ Future <int >
setVideoStreamLayerCount (String channelTag , int layerCount )
→ Future <int >
startChannelMediaRelay (String channelTag , StartOrUpdateChannelMediaRelayRequest request )
→ Future <int >
startScreenCapture (String channelTag , StartScreenCaptureRequest request )
→ Future <int >
stopChannelMediaRelay (String channelTag )
→ Future <int >
stopScreenCapture (String channelTag )
→ Future <int >
subscribeAllRemoteAudio (String channelTag , bool subscribe )
→ Future <int >
subscribeRemoteAudio (String channelTag , int uid , bool subscribe )
→ Future <int >
subscribeRemoteData (String channelTag , bool subscribe , int userID )
→ Future <int >
subscribeRemoteSubAudio (String channelTag , int uid , bool subscribe )
→ Future <int >
subscribeRemoteSubVideoStream (String channelTag , int uid , bool subscribe )
→ Future <int >
subscribeRemoteVideoStream (String channelTag , SubscribeRemoteVideoStreamRequest request )
→ Future <int >
switchCamera (String channelTag )
→ Future <int >
switchCameraWithPosition (String channelTag , int position )
→ Future <int >
takeLocalSnapshot (String channelTag , int streamType , String path )
→ Future <int >
takeRemoteSnapshot (String channelTag , int uid , int streamType , String path )
→ Future <int >
toString ()
→ String
A string representation of this object.
inherited
updateChannelMediaRelay (String channelTag , StartOrUpdateChannelMediaRelayRequest request )
→ Future <int >
updateLiveStreamTask (String channelTag , AddOrUpdateLiveStreamTaskRequest request )
→ Future <int >
updateSelfPosition (String channelTag , PositionInfo positionInfo )
→ Future <int >
nertc_core_platform_interface 5.9.40