FirstVideoFrameDecodedEvent class

Constructors

FirstVideoFrameDecodedEvent({required int uid, required int width, required int height, int? streamType})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamType ↔ int?
getter/setter pair
uid ↔ int
getter/setter pair
width ↔ int
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → FirstVideoFrameDecodedEvent