PlayEffectRequest class

Constructors

PlayEffectRequest({int? effectId, String? path, int? loopCount, bool? sendEnabled, int? sendVolume, bool? playbackEnabled, int? playbackVolume, int? startTimestamp, int? sendWithAudioType, int? progressInterval})

Properties

effectId ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loopCount ↔ int?
getter/setter pair
path ↔ String?
getter/setter pair
playbackEnabled ↔ bool?
getter/setter pair
playbackVolume ↔ int?
getter/setter pair
progressInterval ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendEnabled ↔ bool?
getter/setter pair
sendVolume ↔ int?
getter/setter pair
sendWithAudioType ↔ int?
getter/setter pair
startTimestamp ↔ int?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → PlayEffectRequest