PositionInfo class

Constructors

PositionInfo({required List<double?> mSpeakerPosition, required List<double?> mSpeakerQuaternion, required List<double?> mHeadPosition, required List<double?> mHeadQuaternion})

Properties

hashCode → int
The hash code for this object.
no setterinherited
mHeadPosition ↔ List<double?>
getter/setter pair
mHeadQuaternion ↔ List<double?>
getter/setter pair
mSpeakerPosition ↔ List<double?>
getter/setter pair
mSpeakerQuaternion ↔ List<double?>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → PositionInfo