RequestLLMRequest class

请求LLM的请求对象

Constructors

RequestLLMRequest({required int dstUid, required NERtcLLMRequestParams params})

Properties

dstUid ↔ int
AI在会中的uid,默认可以写0,sdk会自动查找
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
params ↔ NERtcLLMRequestParams
LLM请求参数
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → RequestLLMRequest