SetLocalVideoConfigRequest class

Constructors

SetLocalVideoConfigRequest({int? videoProfile, int? videoCropMode, bool? frontCamera, int? frameRate, int? minFrameRate, int? bitrate, int? minBitrate, int? degradationPrefer, int? width, int? height, int? cameraType, int? mirrorMode, int? orientationMode, int? streamType})

Properties

bitrate ↔ int?
getter/setter pair
cameraType ↔ int?
getter/setter pair
degradationPrefer ↔ int?
getter/setter pair
frameRate ↔ int?
getter/setter pair
frontCamera ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
getter/setter pair
minBitrate ↔ int?
getter/setter pair
minFrameRate ↔ int?
getter/setter pair
mirrorMode ↔ int?
getter/setter pair
orientationMode ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamType ↔ int?
getter/setter pair
videoCropMode ↔ int?
getter/setter pair
videoProfile ↔ int?
getter/setter pair
width ↔ int?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → SetLocalVideoConfigRequest