SetMultiPathOptionRequest class

Constructors

SetMultiPathOptionRequest({bool? enableMediaMultiPath, int? mediaMode, int? badRttThreshold, bool? redAudioPacket, bool? redAudioRtxPacket, bool? redVideoPacket, bool? redVideoRtxPacket})

Properties

badRttThreshold ↔ int?
getter/setter pair
enableMediaMultiPath ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mediaMode ↔ int?
getter/setter pair
redAudioPacket ↔ bool?
getter/setter pair
redAudioRtxPacket ↔ bool?
getter/setter pair
redVideoPacket ↔ bool?
getter/setter pair
redVideoRtxPacket ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → SetMultiPathOptionRequest