SetVideoCorrectionConfigRequest class

Constructors

SetVideoCorrectionConfigRequest({CGPoint? topLeft, CGPoint? topRight, CGPoint? bottomLeft, CGPoint? bottomRight, double? canvasWidth, double? canvasHeight, bool? enableMirror})

Properties

bottomLeft ↔ CGPoint?
getter/setter pair
bottomRight ↔ CGPoint?
getter/setter pair
canvasHeight ↔ double?
getter/setter pair
canvasWidth ↔ double?
getter/setter pair
enableMirror ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeft ↔ CGPoint?
getter/setter pair
topRight ↔ CGPoint?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → SetVideoCorrectionConfigRequest