StartOrUpdateChannelMediaRelayRequest class

Constructors

StartOrUpdateChannelMediaRelayRequest({Map<Object?, Object?>? sourceMediaInfo, Map<Object?, Map<Object?, Object?>?>? destMediaInfo})

Properties

destMediaInfo ↔ Map<Object?, Map<Object?, Object?>?>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceMediaInfo ↔ Map<Object?, Object?>?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited