StartScreenCaptureRequest class

Constructors

StartScreenCaptureRequest({int? contentPrefer, int? videoProfile, int? frameRate, int? minFrameRate, int? bitrate, int? minBitrate, Map<String?, Object?>? dict})

Properties

bitrate ↔ int?
getter/setter pair
contentPrefer ↔ int?
getter/setter pair
dict ↔ Map<String?, Object?>?
getter/setter pair
frameRate ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minBitrate ↔ int?
getter/setter pair
minFrameRate ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoProfile ↔ int?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → StartScreenCaptureRequest