UserLeaveEvent class

Constructors

UserLeaveEvent({required int uid, required int reason, NERtcUserLeaveExtraInfo? leaveExtraInfo})

Properties

hashCode → int
The hash code for this object.
no setterinherited
leaveExtraInfo ↔ NERtcUserLeaveExtraInfo?
getter/setter pair
reason ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid ↔ int
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → UserLeaveEvent