VideoFrame class

Constructors

VideoFrame({int? width, int? height, int? rotation, int? format, int? timeStamp, Uint8List? data, int? strideY, int? strideU, int? strideV, int? textureId, List<double?>? transformMatrix})

Properties

data ↔ Uint8List?
getter/setter pair
format ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
getter/setter pair
rotation ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strideU ↔ int?
getter/setter pair
strideV ↔ int?
getter/setter pair
strideY ↔ int?
getter/setter pair
textureId ↔ int?
getter/setter pair
timeStamp ↔ int?
getter/setter pair
transformMatrix ↔ List<double?>?
getter/setter pair
width ↔ int?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → VideoFrame