VideoRendererApi class

Constructors

VideoRendererApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for VideoRendererApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger → BinaryMessenger?
final
pigeonVar_messageChannelSuffix → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createVideoRenderer() → Future<int>
disposeVideoRenderer(int textureId) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMirror(int textureId, bool mirror) → Future<int>
setupLocalSubStreamVideoRenderer(int textureId, String channelTag) → Future<int>
setupLocalVideoRenderer(int textureId, String channelTag) → Future<int>
setupPlayStreamingCanvas(String streamId, int textureId) → Future<int>
setupRemoteSubStreamVideoRenderer(int uid, int textureId, String channelTag) → Future<int>
setupRemoteVideoRenderer(int uid, int textureId, String channelTag) → Future<int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>