VideoWatermarkConfig class

视频水印设置,目前支持三种类型的水印,但只能其中选择一种水印生效

Constructors

VideoWatermarkConfig({required NERtcVideoWatermarkType WatermarkType, VideoWatermarkImageConfig? imageWatermark, VideoWatermarkTextConfig? textWatermark, VideoWatermarkTimestampConfig? timestampWatermark})

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageWatermark ↔ VideoWatermarkImageConfig?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textWatermark ↔ VideoWatermarkTextConfig?
getter/setter pair
timestampWatermark ↔ VideoWatermarkTimestampConfig?
getter/setter pair
WatermarkType ↔ NERtcVideoWatermarkType
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → VideoWatermarkConfig