VideoWatermarkImageConfig class

Constructors

VideoWatermarkImageConfig({double? wmAlpha, int? wmWidth, int? wmHeight, int? offsetX, int? offsetY, List<String?>? imagePaths, int? fps, bool? loop})

Properties

fps ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imagePaths ↔ List<String?>?
getter/setter pair
loop ↔ bool?
getter/setter pair
offsetX ↔ int?
getter/setter pair
offsetY ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wmAlpha ↔ double?
getter/setter pair
wmHeight ↔ int?
getter/setter pair
wmWidth ↔ int?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → VideoWatermarkImageConfig