VideoWatermarkTimestampConfig class

Constructors

VideoWatermarkTimestampConfig({double? wmAlpha, int? wmWidth, int? wmHeight, int? offsetX, int? offsetY, int? wmColor, int? fontSize, int? fontColor, String? fontNameOrPath})

Properties

fontColor ↔ int?
getter/setter pair
fontNameOrPath ↔ String?
getter/setter pair
fontSize ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offsetX ↔ int?
getter/setter pair
offsetY ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wmAlpha ↔ double?
getter/setter pair
wmColor ↔ int?
getter/setter pair
wmHeight ↔ int?
getter/setter pair
wmWidth ↔ int?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → VideoWatermarkTimestampConfig